@@ -24,9 +24,9 @@ class ConsolidateParameters(ProcessorParameters):
     <li>**unknown** to retain all but prepending the `unknown_prefix` to the label of unknown entities<br />
     <li>**unknown_only** to retain only unknown entities prepending `unknown_prefix` to their label br />""",
     )
-    kill_label: Optional[str] = Field(None, description="Label name of the kill list")
+    kill_label: Optional[str] = Field(None, description="Label name of the kill list", extra="label")
     unknown_prefix: Optional[str] = Field(
-        "Unknown ", description="String to prepend to the label of 'unknown' entities"
+        "Unknown ", description="String to prepend to the label of 'unknown' entities", extra="advanced"
     )
 
 
@@ -49,7 +49,7 @@ class ConsolidateProcessor(ProcessorBase):
                 ]:
                     for a in anns:
                         unknown_labelName = sanitize_label(
-                            params.unknown_prefix + a.label
+                            params.unknown_prefix + (a.label or a.labelName)
                         )
                         if not has_knowledge(a):
                             a.labelName = unknown_labelName
@@ -106,8 +106,10 @@ class ConsolidateProcessor(ProcessorBase):
                             props = target.properties or {}
                             props.update(ann.properties)
                             target.properties = props
+        if kill_label is not None:
+            result = [ann for ann in result if ann.labelName != kill_label]
         result = sorted(
-            [ann for ann in result if ann.labelName != kill_label],
+            result,
             key=lambda ann: ann.start,
         )
         return result
