@@ -154,3 +154,6 @@ def test_acronyms():
         assert len(consolidated_groups_label["Expanded"]) > 0
         assert len(consolidated_groups_label["concept_4_3"]) > 0
         assert len(consolidated_groups_label["unknown_concept_4_3"]) > 0
+        result = Path(testdir, "data/acronyms_conso.json")
+        with result.open("w") as fout:
+            json.dump(consolidated.dict(), fout, indent=2)
